/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.util.Collection;

/**
 * Tasks of Interface Transferable.
 * <ol>
 * <li>A Transferable is a Object, wich is Transported between the Backend and Frontend of the System</li>
 * <li>It holds a PayLoad wich could be writen to different DCPs</li>
 * <li>It holds a Set of TransferAttributes, wich describe the special aspects of the payload, or holds other special
 * Information for different DCPs</li>
 * </ol>
 *
 */
public interface Transferable {
    /**
     * Gets the PayLoad of this Transferable.
     *
     * @return
     */
    Payload getPayload();

    /**
     * Sets the Payload of this Transferable.
     */
    void setPayload(Payload pPayload);

    /**
     * Returns the Collection of keys, under which TransferAttributes.
     * are stored
     *
     * @return
     */
    Collection<String> getAttributeNames();

    /**
     * Returns the Collection of TransferAttributes which stored in.
     * this Transferable
     *
     * @return
     */
    Collection<TransferAttribute> getAttributes();

    /**
     * Gets the TransferAttribute which are stored under pName.
     *
     * @param pName
     * @return null <==> (!getAttributeNames.contains(pKey) || pKey==null)
     */
    TransferAttribute getAttribute(String pName);

    /**
     * Gets the Value of the TransferAttribute which are stored under pName.
     *
     * @param pName
     * @return null <==> (!getAttributeNames.contains(pName) || pName==null) <br/>
     *         short for getAttribute(pName).getValue();
     */
    Object getAttributeValue(String pName);

    /**
     * Adds a Attribute to the Set and stores it under pAttribute.getName().
     *
     * @param pAttribute
     *            The Attribute
     */
    void addAttribute(TransferAttribute pAttribute);

    /**
     * Removes an attribute from the transferable.
     *
     * @param name
     *            the attribute name.
     */
    void removeAttribute(String name);
}
