/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.attributes;

/**
 * The interface AttributeValue encapsulates different value types.
 * <p/>
 *
 * @author Marko Reiprecht
 * @version $Revision: 2281 $
 */
public interface AttributeValue {

    // ------------------------------ FIELDS ------------------------------

    /**
     * Field EMPTY_VALUE represents a null or empty attribute value.
     * Instead of creating instances of
     * class {@link org.n52.security.common.attributes.EmptyAttributeValue}
     * this field shall be used.
     */
    AttributeValue EMPTY_VALUE = new EmptyAttributeValue();

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Gets the type name of the concrete value.
     * This should be a short cut to getUnspecifiedValue().getClass().getName(),
     * but can also be used for other purposes, e.g. xacml type names etc.
     *
     * @return a type name.
     */
    String getTypeName();

    /**
     * Gets the concrete value as "object".
     * But typical there is a cast to a concrete AttributeValue class.
     *
     * @return the wrapped concrete value.
     */
    Object getUnspecifiedValue();
}
