/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.attributes;

import java.io.Serializable;

/**
 * Class BooleanAttributeValue represents a boolean attribute value.
 *
 * @author Marko Reiprecht
 *         Created on 27.03.2007
 * @version $Revision: 2281 $
 */
public class BooleanAttributeValue extends AttributeValueAdapter implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    /**
     * Field serialVersionUID.
     */
    private static final long serialVersionUID = 4735885135171208562L;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * creates new BooleanAttributeValue.
     *
     * @param wrappedObject the concrete boolean object, asserts wrappedObject != null.
     * @throws NullPointerException if wrappedObject is null.
     */
    public BooleanAttributeValue(final Boolean wrappedObject) throws NullPointerException {
        super(wrappedObject);
    }

    /**
     * creates new BooleanAttributeValue.
     *
     * @param wrappedObject the boolean value.
     */
    public BooleanAttributeValue(final boolean wrappedObject) {
        this(Boolean.valueOf(wrappedObject));
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method getBooleanValue returns the booleanValue of this BooleanAttributeValue object.
     *
     * @return the booleanValue (type boolean) of this BooleanAttributeValue object.
     */
    public boolean getBooleanValue() {
        return getValue().booleanValue();
    }

    /**
     * Method getValue returns the value of this BooleanAttributeValue object.
     *
     * @return the value (type Boolean) of this BooleanAttributeValue object.
     */
    public Boolean getValue() {
        return (Boolean) m_wrappedObject;
    }
}
