/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.attributes;

import java.io.Serializable;

/**
 * Class DoubleAttributeValue represents a double attribute value.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 26.03.2007
 * @version $Revision: 2281 $
 */
public class DoubleAttributeValue extends AttributeValueAdapter implements Serializable {

    // ------------------------------ FIELDS ------------------------------

    /** Field serialVersionUID.  */
    private static final long serialVersionUID = 6193490029090379287L;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor DoubleAttributeValue creates a new DoubleAttributeValue instance.
     *
     * @param wrappedObject of type double
     */
    public DoubleAttributeValue(final double wrappedObject) {
        super(new Double(wrappedObject));
    }

    /**
     * Constructor DoubleAttributeValue creates a new DoubleAttributeValue instance.
     *
     * @param wrappedObject of type Double
     * @throws NullPointerException when wrappedObject is null
     */
    public DoubleAttributeValue(final Double wrappedObject) throws NullPointerException {
        super(wrappedObject);
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method getDoubleValue returns the doubleValue of this DoubleAttributeValue object.
     *
     * @return the doubleValue (type double) of this DoubleAttributeValue object.
     */
    public double getDoubleValue() {
        return getValue().doubleValue();
    }

    /**
     * Method getValue returns the value of this DoubleAttributeValue object.
     *
     * @return the value (type Double) of this DoubleAttributeValue object.
     */
    public Double getValue() {
        return (Double) m_wrappedObject;
    }
}
