/* Copyright (C) 2011 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 */
package org.n52.security.common.collections;

import java.util.Iterator;

/**
 * 
 */
public class FilterIterator<NewType, OldType> implements Iterator<NewType> {

    private Iterator<OldType> m_decoratedIterator;
    private Filter<NewType, OldType> m_filter;

    private boolean m_hasNext;
    private NewType m_next;

    public FilterIterator(Iterator<OldType> decoratedIterator, Filter<NewType, OldType> filter) {
        m_decoratedIterator = decoratedIterator;
        m_filter = filter;
        findNext();
    }

    @Override
    public boolean hasNext() {
        return m_hasNext;
    }

    private void findNext() {
        boolean hasNext = false;
        NewType next = null;
        while (!hasNext && m_decoratedIterator.hasNext()) {
            OldType newInstance = m_decoratedIterator.next();
            if (m_filter.accept(newInstance)) {
                next = m_filter.transform(newInstance);
                hasNext = true;
            }
        }
        m_next = next;
        m_hasNext = hasNext;
    }

    @Override
    public NewType next() {
        NewType next = m_next;
        findNext();
        return next;
    }

    @Override
    public void remove() {
        throw new UnsupportedOperationException("<remove> is not implemented on decorated iterators");
    }

}
