/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.crypto;

import java.util.HashMap;
import java.util.Map;

/**
 * Wraps incomming alias names to aliasnames used in the decorated provider.
 * If the name can't be mapped the incomming names is given to the decorated provider.
 * 
 * @author Marko Reiprecht
 */
public class AliasMappingKeyProviderDecorator extends AbstractKeyPairProviderDecorator {

    private Map<String, String> m_aliasToKeyAliasMap = new HashMap<String, String>();

    /**
     * @return the aliasToKeyAliasMap
     */
    public Map<String, String> getAliasToKeyAliasMap() {
        return m_aliasToKeyAliasMap;
    }

    /**
     * It is espected that the incoming alias names are used as keys and the internal/outcomming alias names are used as
     * values.
     * 
     * @param aliasToKeyAliasMap
     *            the aliasToKeyAliasMap to set
     */
    public void setAliasToKeyAliasMap(final Map<String, String> aliasToKeyAliasMap) {
        if (aliasToKeyAliasMap == null) {
            throw new IllegalArgumentException("aliasToKeyAliasMap must not null");
        }
        m_aliasToKeyAliasMap = aliasToKeyAliasMap;
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AliasMappingKeyProviderDecorator() {
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AliasMappingKeyProviderDecorator(final KeyPairProvider delegate) {
        super(delegate);
    }

    /**
     * @see org.n52.security.common.crypto.AbstractKeyPairProviderDecorator#resolveByAlias(java.lang.String, char[])
     */
    public KeyPair resolveByAlias(final String alias, final char[] password) throws KeyPairResolvingException {
        String newAlias = (String) getAliasToKeyAliasMap().get(alias);
        return super.resolveByAlias(newAlias != null ? newAlias : alias, password);
    }

}
