/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.crypto;

import java.math.BigInteger;
import java.security.cert.Certificate;

/**
 * Interface KeyPairProvider encapsulates typical resolving methods of cryptographic keys.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public interface KeyPairProvider {

    /**
     * Method resolves a keypair by an alias.
     * The provider tries to resolve the private key and its public key or certificate.
     * Only if none of the elements can be resolved an exception is thrown.
     *
     * @param alias    the alias.
     * @param password a password for the private key, can be null.
     * @return KeyPair.
     * @throws KeyPairResolvingException if keypair can't be resolved.
     */
    KeyPair resolveByAlias(String alias, char[] password) throws KeyPairResolvingException;

    /**
     * Method resolves a key pair by a SerialIssuer, this is required to resolve certificates and
     * it's private keys by the id of the certificate.
     * Only if none of the elements can be resolved an exception is thrown.
     *
     * @param issuerDN the issuerDN.
     * @param serial   the serial.
     * @param password a password for the private key, can be null.
     * @return KeyPair.
     * @throws KeyPairResolvingException if error occurs.
     */
    KeyPair resolveBySerialIssuer(final String issuerDN, final BigInteger serial, char[] password)
            throws KeyPairResolvingException;


    /**
     * Method resolves a key pair by a given certificate.
     * Only if none of the elements can be resolved an exception is thrown.
     *
     * @param cert     the cert.
     * @param password a password for the private key, can be null.
     * @return KeyPair.
     * @throws KeyPairResolvingException if error occurs.
     */
    KeyPair resolveByCertificate(final Certificate cert, char[] password) throws KeyPairResolvingException;
}