/* Copyright (C) 2011 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 */
package org.n52.security.common.crypto;

import static org.n52.security.common.collections.CollectionUtil.asArray;
import static org.n52.security.common.collections.CollectionUtil.transform;

import java.net.Socket;
import java.security.Principal;
import java.security.PrivateKey;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.Arrays;

import javax.net.ssl.X509ExtendedKeyManager;

import org.n52.security.common.collections.AbstractTransformerFilter;

/**
 * Adapter of ssl keymanager to keypair.
 * Can be used to create a ssl socket with a given keypair.
 */
public class KeyPairX509KeyManager extends X509ExtendedKeyManager {

    private KeyPair m_keypair;

    public KeyPairX509KeyManager(KeyPair keypair) {
        if (keypair == null) {
            throw new IllegalArgumentException("<keypair> must not null!");
        }
        m_keypair = keypair;
    }

    @Override
    public String chooseClientAlias(String[] keyType, Principal[] issuers, Socket socket) {
        return m_keypair.getAlias();
    }

    @Override
    public String chooseServerAlias(String keyType, Principal[] issuers, Socket socket) {
        return m_keypair.getAlias();
    }

    @Override
    public X509Certificate[] getCertificateChain(String alias) {
        if (m_keypair.isCertificateChainSet()) {
            return asArray(X509Certificate.class, transform(Arrays.asList(m_keypair.getCertificateChain()),
                    new AbstractTransformerFilter<X509Certificate, Certificate>() {
                        @Override
                        public X509Certificate transform(Certificate instance) {
                            return (X509Certificate) instance;
                        }
                    }));
        }
        return new X509Certificate[] { (X509Certificate) m_keypair.getCertificate() };
    }

    @Override
    public PrivateKey getPrivateKey(String alias) {
        if (alias.equals(m_keypair.getAlias())) {
            return (PrivateKey) m_keypair.getPrivateKey();
        }
        throw new IllegalArgumentException("alias <" + alias + "> is unknown!");
    }

    @Override
    public String[] getServerAliases(String keyType, Principal[] issuers) {
        return new String[] { m_keypair.getAlias() };
    }

    @Override
    public String[] getClientAliases(String keyType, Principal[] issuers) {
        return getServerAliases(keyType, issuers);
    }

}
