/*******************************************************************************
 * Copyright (C) 2011
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 ******************************************************************************/
package org.n52.security.common.crypto;


/**
 * @author jdr
 *
 */
public class X509Name {

    private final String m_dnName;

    public X509Name(String name) {
        m_dnName = name;
    }

    public String getDnName() {
        return m_dnName;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((m_dnName == null) ? 0 : m_dnName.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        X509Name other = (X509Name) obj;
        if (m_dnName == null) {
            if (other.m_dnName != null)
                return false;
        } else {
            return equalIssuerDN(m_dnName, other.getDnName());
        }
        return true;
    }

    private boolean equalIssuerDN(final String theFirstIssuer, final String theSecondIssuer) {
        X509NameTokenizer certIssuer = new X509NameTokenizer(theFirstIssuer);
        X509NameTokenizer toTest = new X509NameTokenizer(theSecondIssuer);
        while (certIssuer.hasMoreTokens()) {
            if (!toTest.hasMoreTokens() || !certIssuer.nextToken().equals(toTest.nextToken())) {
                return false;
            }
        }
        return !toTest.hasMoreTokens();
    }


}
