/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.ip;

import java.net.InetAddress;

/**
 * Represents a rage of contiguous IP addresses.
 * 
 * @author jdr
 *
 */
public interface IPRange {

    
    /**
     * Checks whether a given IP address is part of this IP address range.
     * 
     * @param address the address to test.
     * @return <code>true</code> if the specified address is in the range, <code>false</code> otherwise.
     */
    boolean contains(InetAddress address);
    
    /**
     * @return IP address that is the upper border of the range. 
     */
    InetAddress first();
    
    /**
     * @return IP address that is the lower border of the range. 
     */
    InetAddress last();
        
}
