/*******************************************************************************
 * Copyright (C) 2010 by 52 North Initiative for Geospatial Open Source Software
 * GmbH
 * 
 * Contact: Andreas Wytzisk 52 North Initiative for Geospatial Open Source
 * Software GmbH Martin-Luther-King-Weg 24 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/
package org.n52.security.common.util;

public class KeyValuePair {

    private String m_key;
    
    private String m_value;
    
    public KeyValuePair(String key, String value) {
        setKey(key);
        setValue(value);
    }

    public void setKey(String key) {
        if (key == null) {
            throw new IllegalArgumentException("'key' must not be null.");
        }
        m_key = key;
    }

    public String getKey() {
        return m_key;
    }

    public void setValue(String value) {
        m_value = value;
        if (m_value == null) {
            m_value = "";
        }
    }

    public String getValue() {
        return m_value;
    }
    
    public boolean isValueEmpty() {
        return m_value == null || m_value.isEmpty();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((m_key == null) ? 0 : m_key.hashCode());
        result = prime * result + ((m_value == null) ? 0 : m_value.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        KeyValuePair other = (KeyValuePair) obj;
        if (m_key == null) {
            if (other.m_key != null)
                return false;
        } else if (!m_key.equals(other.m_key))
            return false;
        if (m_value == null) {
            if (other.m_value != null)
                return false;
        } else if (!m_value.equals(other.m_value))
            return false;
        return true;
    }
    
    public String toString() {
        return m_key + "=" + m_value;
    }
    
    
}
