/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 23.03.2008
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import java.io.InputStream;
import java.io.Reader;
import java.io.StringReader;

import org.w3c.dom.ls.LSInput;
import org.xml.sax.InputSource;

/**
 * Class LSInputSourceAdapter adapts the LSInput interface to the 'old' InputSource interface.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 23.03.2008
 * @version $Revision: $
 */
public class LSInputSourceAdapter implements LSInput {

    // ------------------------------ FIELDS ------------------------------

    private InputSource m_inputSource;
    private String m_baseUri;
    private boolean m_certifiedText;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     *
     * @param inputSource the inputSource.
     */
    public LSInputSourceAdapter(final InputSource inputSource) {
        this(inputSource, null);
    }

    /**
     * Constructor creates a new instance.
     *
     * @param inputSource the inputSource.
     * @param baseUri     the baseUri.
     */
    public LSInputSourceAdapter(final InputSource inputSource, final String baseUri) {
        this(inputSource, baseUri, false);
    }

    /**
     * Constructor creates a new instance.
     *
     * @param inputSource   the inputSource.
     * @param baseUri       the baseUri.
     * @param certifiedText the certifiedText.
     */
    public LSInputSourceAdapter(final InputSource inputSource, final String baseUri, final boolean certifiedText) {
        if (inputSource == null) {
            throw new IllegalArgumentException("inputSource must not null");
        }
        m_inputSource = inputSource;
        m_baseUri = baseUri;
        m_certifiedText = certifiedText;
    }

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the baseURI.
     *
     * @return String.
     */
    public String getBaseURI() {
        return m_baseUri;
    }

    /**
     * Method sets the baseURI.
     *
     * @param baseURI the baseURI.
     */
    public void setBaseURI(final String baseURI) {
        m_baseUri = baseURI;
    }

    /**
     * Method gets the byteStream.
     *
     * @return InputStream.
     */
    public InputStream getByteStream() {
        return m_inputSource.getByteStream();
    }

    /**
     * Method sets the byteStream.
     *
     * @param byteStream the byteStream.
     */
    public void setByteStream(final InputStream byteStream) {
        m_inputSource.setByteStream(byteStream);
    }

    /**
     * Method gets the certifiedText.
     *
     * @return boolean.
     */
    public boolean getCertifiedText() {
        return m_certifiedText;
    }

    /**
     * Method sets the certifiedText.
     *
     * @param certifiedText the certifiedText.
     */
    public void setCertifiedText(final boolean certifiedText) {
        m_certifiedText = certifiedText;
    }

    /**
     * Method gets the characterStream.
     *
     * @return Reader.
     */
    public Reader getCharacterStream() {
        return m_inputSource.getCharacterStream();
    }

    /**
     * Method sets the characterStream.
     *
     * @param characterStream the characterStream.
     */
    public void setCharacterStream(final Reader characterStream) {
        m_inputSource.setCharacterStream(characterStream);
    }

    /**
     * Method gets the encoding.
     *
     * @return String.
     */
    public String getEncoding() {
        return m_inputSource.getEncoding();
    }

    /**
     * Method sets the encoding.
     *
     * @param encoding the encoding.
     */
    public void setEncoding(final String encoding) {
        m_inputSource.setEncoding(encoding);
    }

    /**
     * Method gets the publicId.
     *
     * @return String.
     */
    public String getPublicId() {
        return m_inputSource.getPublicId();
    }

    /**
     * Method sets the publicId.
     *
     * @param publicId the publicId.
     */
    public void setPublicId(final String publicId) {
        m_inputSource.setPublicId(publicId);
    }

    /**
     * Method gets the stringData.
     *
     * @return String.
     */
    public String getStringData() {
        return null;
    }

    /**
     * Method sets the stringData.
     *
     * @param stringData the stringData.
     */
    public void setStringData(final String stringData) {
        m_inputSource.setCharacterStream(new StringReader(stringData));
    }

    /**
     * Method gets the systemId.
     *
     * @return String.
     */
    public String getSystemId() {
        return m_inputSource.getSystemId();
    }

    /**
     * Method sets the systemId.
     *
     * @param systemId the systemId.
     */
    public void setSystemId(final String systemId) {
        m_inputSource.setSystemId(systemId);
    }
}
